#include "BrainCloudGlobalEntity.h"


#include "BrainCloudClient.h"
#include "ServerCall.h"
#include "StringUtil.h"

namespace BrainCloud {

	BrainCloudGlobalEntity::BrainCloudGlobalEntity()
	{
	}


	BrainCloudGlobalEntity::~BrainCloudGlobalEntity()
	{
	}

	void BrainCloudGlobalEntity::createEntity(std::string& in_entityType, int64_t in_timeToLive, std::string& in_jsonEntityAcl,
		std::string& in_jsonEntityData, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceEntityType.getValue()] = in_entityType;
        message[OperationParam::GlobalEntityServiceTimeToLive.getValue()] = (Json::Int64) in_timeToLive;
		message[OperationParam::GlobalEntityServiceData.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_jsonEntityData);
		message[OperationParam::GlobalEntityServiceAcl.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_jsonEntityAcl);

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::Create, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::createEntityWithIndexedId(std::string& in_entityType, std::string& in_indexedId, int64_t in_timeToLive,
		std::string& in_jsonEntityAcl, std::string& in_jsonEntityData, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceEntityType.getValue()] = in_entityType;
		message[OperationParam::GlobalEntityServiceIndexedId.getValue()] = in_indexedId;
        message[OperationParam::GlobalEntityServiceTimeToLive.getValue()] = (Json::Int64) in_timeToLive;
		message[OperationParam::GlobalEntityServiceData.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_jsonEntityData);
		message[OperationParam::GlobalEntityServiceAcl.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_jsonEntityAcl);

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::CreateWithIndexedId, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::updateEntity(std::string& in_entityId, int64_t in_version, std::string& in_jsonEntityData, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceEntityId.getValue()] = in_entityId;
		message[OperationParam::GlobalEntityServiceVersion.getValue()] = (Json::Int64) in_version;
		message[OperationParam::GlobalEntityServiceData.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_jsonEntityData);

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::Update, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::updateEntityAcl(std::string& in_entityId, int64_t in_version, std::string& in_jsonEntityAcl, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceEntityId.getValue()] = in_entityId;
		message[OperationParam::GlobalEntityServiceVersion.getValue()] = (Json::Int64) in_version;
		message[OperationParam::GlobalEntityServiceAcl.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_jsonEntityAcl);

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::UpdateAcl, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::updateEntityTimeToLive(std::string& in_entityId, int64_t in_version, int64_t in_timeToLive, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceEntityId.getValue()] = in_entityId;
		message[OperationParam::GlobalEntityServiceVersion.getValue()] = (Json::Int64) in_version;
        message[OperationParam::GlobalEntityServiceTimeToLive.getValue()] = (Json::Int64) in_timeToLive;

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::UpdateTimeToLive, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::deleteEntity(std::string& in_entityId, int64_t in_version, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceEntityId.getValue()] = in_entityId;
		message[OperationParam::GlobalEntityServiceVersion.getValue()] = (Json::Int64) in_version;

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::Delete, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::readEntity(std::string& in_entityId, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceEntityId.getValue()] = in_entityId;

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::Read, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::getList(std::string& in_where, std::string& in_orderBy, int64_t in_maxReturn, IServerCallback * in_callback)
	{
		Json::Value message;
        
        if (StringUtil::IsOptionalParameterValid(in_where)) {
            message[OperationParam::GlobalEntityServiceWhere.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_where);
        }
        
        if (StringUtil::IsOptionalParameterValid(in_orderBy)) {
            message[OperationParam::GlobalEntityServiceOrderBy.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_orderBy);
        }
        
		message[OperationParam::GlobalEntityServiceMaxReturn.getValue()] = (Json::Int64) in_maxReturn;

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::GetList, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::getListByIndexedId(std::string& in_entityIndexedId, int64_t in_maxReturn, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceIndexedId.getValue()] = in_entityIndexedId;
		message[OperationParam::GlobalEntityServiceMaxReturn.getValue()] = (Json::Int64) in_maxReturn;

		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::GetListByIndexedId, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}

	void BrainCloudGlobalEntity::getListCount(std::string& in_where, IServerCallback * in_callback)
	{
		Json::Value message;
		message[OperationParam::GlobalEntityServiceWhere.getValue()] = BrainCloudClient::getInstance()->jsonStringToValue(in_where);
		
		ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::GetListCount, message, in_callback);
		BrainCloudClient::getInstance()->sendRequest(sc);
	}
    
    void BrainCloudGlobalEntity::getPage(const char * in_context, IServerCallback * in_callback)
    {
        Json::Value message;
        Json::Reader reader;
        
        Json::Value parsedContext;
        reader.parse(in_context, parsedContext);
        message[OperationParam::GlobalEntityServiceContext.getValue()] = parsedContext;
        
        ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::GetPage, message, in_callback);
        BrainCloudClient::getInstance()->sendRequest(sc);
    }
    
    void BrainCloudGlobalEntity::getPageOffset(const char * in_context, int in_pageOffset, IServerCallback * in_callback)
    {
        Json::Value message;
        Json::Reader reader;
        
        message[OperationParam::GlobalEntityServiceContext.getValue()] = in_context;
        message[OperationParam::GlobalEntityServicePageOffset.getValue()] = in_pageOffset;
        
        ServerCall * sc = new ServerCall(ServiceName::GlobalEntity, ServiceOperation::GetPageOffset, message, in_callback);
        BrainCloudClient::getInstance()->sendRequest(sc);
    }
}







